From a8b0da000e9e053be34cf5ed6eb4937103fe9244 Mon Sep 17 00:00:00 2001
From: Jean-Paul Saman <jpsaman@videolan.org>
Date: Thu, 10 May 2012 21:09:10 +0200
Subject: [PATCH 1/2] libvlccore: implement picture_fifo_GetDeltaDate()

The function picture_fifo_GetDeltaDate() calculates the amount of time worth
of pictures is in the fifo. It returns the delta from the last and first
picture date.
---
 include/vlc_picture_fifo.h |    4 ++++
 src/libvlccore.sym         |    1 +
 src/misc/picture_fifo.c    |   22 ++++++++++++++++++++++
 3 files changed, 27 insertions(+), 0 deletions(-)

diff --git a/include/vlc_picture_fifo.h b/include/vlc_picture_fifo.h
index 73d1b20..84801fc 100644
--- a/include/vlc_picture_fifo.h
+++ b/include/vlc_picture_fifo.h
@@ -84,6 +84,10 @@ VLC_API void picture_fifo_Flush( picture_fifo_t *, mtime_t date, bool flush_befo
  */
 VLC_API void picture_fifo_OffsetDate( picture_fifo_t *, mtime_t delta );
 
+/**
+ * It returns the delta of the first and last picture->date in the fifo.
+ */
+VLC_API mtime_t picture_fifo_GetDeltaDate( picture_fifo_t * );
 
 #endif /* VLC_PICTURE_FIFO_H */
 
diff --git a/src/libvlccore.sym b/src/libvlccore.sym
index 5d35457..c7ed256 100644
--- a/src/libvlccore.sym
+++ b/src/libvlccore.sym
@@ -304,6 +304,7 @@ picture_Copy
 picture_Export
 picture_fifo_Delete
 picture_fifo_Flush
+picture_fifo_GetDeltaDate
 picture_fifo_New
 picture_fifo_OffsetDate
 picture_fifo_Peek
diff --git a/src/misc/picture_fifo.c b/src/misc/picture_fifo.c
index 0734ca9..0c7a0a8 100644
--- a/src/misc/picture_fifo.c
+++ b/src/misc/picture_fifo.c
@@ -150,3 +150,25 @@ void picture_fifo_Delete(picture_fifo_t *fifo)
     free(fifo);
 }
 
+mtime_t picture_fifo_GetDeltaDate(picture_fifo_t *fifo)
+{
+    mtime_t delta = 0;
+
+    vlc_mutex_lock(&fifo->lock);
+    picture_t *picture = fifo->first;
+    if (picture)
+    {
+        mtime_t first = picture->date;
+        mtime_t last = 0;
+        while (picture) {
+            picture_t *next = picture->p_next;
+            last = picture->date;
+            picture = next;
+        }
+        if (last > 0)
+            delta = last - first;
+    }
+    vlc_mutex_unlock(&fifo->lock);
+
+    return delta;
+}
-- 
1.7.7.6

